==> kmymoney-5.0.4.tar.xz: kmymoney-5.0.4/kmymoney/plugins/views/onlinejoboutbox/onlinejoboutboxview.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "christian-david@web.de",
                "Name": "Christian Dávid",
                "Name[ca@valencia]": "Christian Dávid",
                "Name[ca]": "Christian Dávid",
                "Name[cs]": "Christian Dávid",
                "Name[en_GB]": "Christian Dávid",
                "Name[es]": "Christian Dávid",
                "Name[fr]": "Christian Dávid",
                "Name[gl]": "Christian Dávid",
                "Name[it]": "Christian Dávid",
                "Name[nl]": "Christian Dávid",
                "Name[pl]": "Christian Dávid",
                "Name[pt]": "Christian Dávid",
                "Name[pt_BR]": "Christian Dávid",
                "Name[ru]": "Christian Dávid",
                "Name[sk]": "Christian Dávid",
                "Name[sv]": "Christian Dávid",
                "Name[uk]": "Christian Dávid",
                "Name[x-test]": "xxChristian Dávidxx"
            }
        ],
        "Description": "Adds online job outbox view to KMyMoney",
        "Description[ca@valencia]": "Afig la vista en línia de l'eixida dels treballs al KMyMoney",
        "Description[ca]": "Afegeix la vista en línia de la sortida dels treballs al KMyMoney",
        "Description[en_GB]": "Adds online job outbox view to KMyMoney",
        "Description[es]": "Añade la vista de la bandeja de salida de trabajos en línea a KMyMoney",
        "Description[fr]": "Ajoute la vue boîte d'envoi des tâches en ligne à KMyMoney",
        "Description[gl]": "Engade unha vista fóra da caixa de traballo por internet a KMyMoney",
        "Description[it]": "Aggiunge la vista delle operazioni in linea in uscita a KMyMoney",
        "Description[ko]": "KMyMoney에 온라인 작업 발신 함보기 추가",
        "Description[nl]": "Voegt online weergave van postvak uit toe aan KMyMoney",
        "Description[pl]": "Dodaje widok skrzynki wyjściowej zadań w sieci do KMyMoney",
        "Description[pt]": "Adiciona a área da caixa de saída das tarefas 'online' ao KMyMoney",
        "Description[pt_BR]": "Adiciona área da caixa de saída das tarefas online",
        "Description[sv]": "Lägger till utkorgsvy för nätjobb i KMyMoney",
        "Description[uk]": "Панель вихідних інтернет-завдань у KMyMoney",
        "Description[x-test]": "xxAdds online job outbox view to KMyMoneyxx",
        "EnabledByDefault": true,
        "Icon": "online-banking",
        "Id": "onlinejoboutboxview",
        "License": "GPL",
        "Name": "Online job outbox view",
        "Name[ca@valencia]": "Vista en línia de l'eixida dels treballs",
        "Name[ca]": "Vista en línia de la sortida dels treballs",
        "Name[en_GB]": "Online job outbox view",
        "Name[es]": "Vista de la bandeja de salida de trabajos en línea",
        "Name[fr]": "Vue boîte d'envoi des tâches en ligne",
        "Name[gl]": "Vista fóra da caixa de traballo por internet",
        "Name[it]": "Vista delle operazioni in linea in uscita",
        "Name[nl]": "Online weergave van postvak uit van job",
        "Name[pl]": "Skrzynka wyjściowa zadań w sieci",
        "Name[pt]": "Caixa de saída das tarefas 'online'",
        "Name[pt_BR]": "Área da caixa de saída das tarefas online",
        "Name[sv]": "Utkorgsvy för nätjobb",
        "Name[uk]": "Панель вихідних даних інтернет-завдань",
        "Name[x-test]": "xxOnline job outbox viewxx",
        "ServiceTypes": [
            "KMyMoney/Plugin"
        ],
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    }
}

==> kmymoney_5.0.8.orig.tar.xz: kmymoney-5.0.8/kmymoney/plugins/views/onlinejoboutbox/onlinejoboutboxview.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "christian-david@web.de",
                "Name": "Christian Dávid",
                "Name[ca@valencia]": "Christian Dávid",
                "Name[ca]": "Christian Dávid",
                "Name[cs]": "Christian Dávid",
                "Name[de]": "Christian Dávid",
                "Name[en_GB]": "Christian Dávid",
                "Name[es]": "Christian Dávid",
                "Name[fr]": "Christian Dávid",
                "Name[gl]": "Christian Dávid",
                "Name[it]": "Christian Dávid",
                "Name[nl]": "Christian Dávid",
                "Name[pl]": "Christian Dávid",
                "Name[pt]": "Christian Dávid",
                "Name[pt_BR]": "Christian Dávid",
                "Name[ru]": "Christian Dávid",
                "Name[sk]": "Christian Dávid",
                "Name[sv]": "Christian Dávid",
                "Name[uk]": "Christian Dávid",
                "Name[x-test]": "xxChristian Dávidxx"
            }
        ],
        "Description": "Adds online job outbox view to KMyMoney",
        "Description[ca@valencia]": "Afig la vista en línia de l'eixida dels treballs al KMyMoney",
        "Description[ca]": "Afegeix la vista en línia de la sortida dels treballs al KMyMoney",
        "Description[en_GB]": "Adds online job outbox view to KMyMoney",
        "Description[es]": "Añade la vista de la bandeja de salida de trabajos en línea a KMyMoney",
        "Description[fr]": "Ajoute la vue boîte d'envoi des tâches en ligne à KMyMoney",
        "Description[gl]": "Engade unha vista fóra da caixa de traballo por Internet a KMyMoney",
        "Description[it]": "Aggiunge la vista delle operazioni in linea in uscita a KMyMoney",
        "Description[ko]": "KMyMoney에 온라인 작업 발신 함보기 추가",
        "Description[nl]": "Voegt online weergave van postvak uit toe aan KMyMoney",
        "Description[pl]": "Dodaje widok skrzynki wyjściowej zadań w sieci do KMyMoney",
        "Description[pt]": "Adiciona a área da caixa de saída das tarefas 'online' ao KMyMoney",
        "Description[pt_BR]": "Adiciona área da caixa de saída das tarefas online",
        "Description[sv]": "Lägger till utkorgsvy för nätjobb i KMyMoney",
        "Description[uk]": "Панель вихідних інтернет-завдань у KMyMoney",
        "Description[x-test]": "xxAdds online job outbox view to KMyMoneyxx",
        "EnabledByDefault": true,
        "Icon": "online-banking",
        "Id": "onlinejoboutboxview",
        "License": "GPL",
        "Name": "Online job outbox view",
        "Name[ca@valencia]": "Vista en línia de l'eixida dels treballs",
        "Name[ca]": "Vista en línia de la sortida dels treballs",
        "Name[en_GB]": "Online job outbox view",
        "Name[es]": "Vista de la bandeja de salida de trabajos en línea",
        "Name[fr]": "Vue boîte d'envoi des tâches en ligne",
        "Name[gl]": "Vista fóra da caixa de traballo por Internet",
        "Name[it]": "Vista delle operazioni in linea in uscita",
        "Name[nl]": "Online weergave van postvak uit van job",
        "Name[pl]": "Skrzynka wyjściowa zadań w sieci",
        "Name[pt]": "Caixa de saída das tarefas 'online'",
        "Name[pt_BR]": "Área da caixa de saída das tarefas online",
        "Name[sv]": "Utkorgsvy för nätjobb",
        "Name[uk]": "Панель вихідних даних інтернет-завдань",
        "Name[x-test]": "xxOnline job outbox viewxx",
        "ServiceTypes": [
            "KMyMoney/Plugin"
        ],
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    }
}
